@@ -54,6 +54,10 @@ class MultiOutputGRF(BaseEstimator):
         pred, var = zip(*[estimator.predict_projection_and_var(X, projector) for estimator in self.estimators_])
         return np.moveaxis(np.array(pred), 0, 1), np.moveaxis(np.array(var), 0, 1)
 
+    def oob_predict(self, Xtrain):
+        pred = [estimator.oob_predict(Xtrain) for estimator in self.estimators_]
+        return np.moveaxis(np.array(pred), 0, 1)
+
     def feature_importances(self, max_depth=4, depth_decay_exponent=2.0):
         res = [estimator.feature_importances(max_depth=max_depth, depth_decay_exponent=depth_decay_exponent)
                for estimator in self.estimators_]
@@ -107,9 +111,9 @@ class CausalForest(BaseGRF):
 
             sum_{child} E[(Y - <theta(child), T> - beta(child))^2 | X=child] weight(child)
 
-          Internally, for the case of more than two treatments or for the case of one treatment with
+          Internally, for the case of more than two treatments or for the case of two treatments with
           ``fit_intercept=True`` then this criterion is approximated by computationally simpler variants for
-          computationaly purposes. In particular, it is replaced by::
+          computational purposes. In particular, it is replaced by::
 
               sum_{child} weight(child) * rho(child).T @ E[(T;1) @ (T;1).T | X in child] @ rho(child)
 
@@ -303,7 +307,7 @@ class CausalForest(BaseGRF):
     warm_start : bool, default=``False``
         When set to ``True``, reuse the solution of the previous call to fit
         and add more estimators to the ensemble, otherwise, just fit a whole
-        new forest.
+        new forest. If ``True``, then `oob_predict` method for out-of-bag predictions is not available.
 
     Attributes
     ----------
@@ -635,7 +639,7 @@ class CausalIVForest(BaseGRF):
     warm_start : bool, default=False
         When set to ``True``, reuse the solution of the previous call to fit
         and add more estimators to the ensemble, otherwise, just fit a whole
-        new forest.
+        new forest. If ``True``, then `oob_predict` method for out-of-bag predictions is not available.
 
     Attributes
     ----------
@@ -908,7 +912,7 @@ class RegressionForest(BaseGRF):
     warm_start : bool, default=False
         When set to ``True``, reuse the solution of the previous call to fit
         and add more estimators to the ensemble, otherwise, just fit a whole
-        new forest.
+        new forest. If ``True``, then `oob_predict` method for out-of-bag predictions is not available.
 
     Attributes
     ----------
